@@ -5,7 +5,6 @@ from typing import List, Optional, Sequence, Set
 
 from pydantic import BaseModel, validate_arguments
 
-from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
 from ..types import AccountType, Currency
@@ -123,7 +122,6 @@ class BaseBalancesResource(ABC):
 
 
 class AsyncBalancesResource(BaseBalancesResource):
-    @cache
     async def get(
         self,
         user_uuid: str,
@@ -145,7 +143,6 @@ class AsyncBalancesResource(BaseBalancesResource):
 
 
 class SyncBalancesResource(BaseBalancesResource):
-    @cache
     def get(
         self,
         user_uuid: str,
