@@ -4,7 +4,6 @@ from typing import Any, Dict, Optional
 
 from pydantic import validate_arguments
 
-from ..cache import cache
 from ..core import BaseClient
 
 POST_PATH = "/users/{user_uuid}/creditreport"
@@ -55,12 +54,10 @@ class BaseCreditReportResource(ABC):
 
 
 class AsyncCreditReportResource(BaseCreditReportResource):
-    @cache
     async def get(self, user_uuid: str) -> Optional[CreditReport]:
         return await self._get(user_uuid)
 
 
 class SyncCreditReportResource(BaseCreditReportResource):
-    @cache
     def get(self, user_uuid: str) -> Optional[CreditReport]:
         return self._client.run(self._get(user_uuid))
