@@ -3,7 +3,6 @@ from typing import List, Optional
 
 from pydantic import BaseModel, validate_arguments
 
-from ..cache import cache
 from ..core import BaseClient
 from ..types import AccountType, Currency
 
@@ -44,12 +43,10 @@ class BaseInstitutionsResource(ABC):
 
 
 class AsyncInstitutionsResource(BaseInstitutionsResource):
-    @cache
     async def get(self, user_uuid: str) -> List[Institution]:
         return await self._get(user_uuid)
 
 
 class SyncInstitutionsResource(BaseInstitutionsResource):
-    @cache
     def get(self, user_uuid: str) -> List[Institution]:
         return self._client.run(self._get(user_uuid))
