@@ -5,7 +5,6 @@ from typing import List, Optional, Sequence, Set
 
 from pydantic import BaseModel, validate_arguments
 
-from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
 from ..types import AccountType, Currency, Impact
@@ -124,7 +123,6 @@ class BaseTransactionsResource(ABC):
 
 
 class AsyncTransactionsResource(BaseTransactionsResource):
-    @cache
     async def get(
         self,
         user_uuid: str,
@@ -146,7 +144,6 @@ class AsyncTransactionsResource(BaseTransactionsResource):
 
 
 class SyncTransactionsResource(BaseTransactionsResource):
-    @cache
     def get(
         self,
         user_uuid: str,
